<?php
/**
 * Theme setup and initialization.
 *
 * @package   BrunchPro
 * @copyright Copyright (c) 2018, Feast Design Co.
 * @license   GPL-2.0+
 * @since     1.0.0
 */

defined( 'WPINC' ) || die;

require_once get_template_directory() . '/lib/init.php';

define( 'CHILD_THEME_NAME', 'Brunch Pro Theme' );
define( 'CHILD_THEME_VERSION', '4.2.0' );
define( 'CHILD_THEME_URL', 'https://feastdesignco.com/product/brunch-pro/' );
define( 'CHILD_THEME_DEVELOPER', 'Feast Design Co.' );
define( 'BRUNCH_PRO_DIR', trailingslashit( get_stylesheet_directory() ) ); // deprecated
define( 'BRUNCH_PRO_URI', trailingslashit( get_stylesheet_directory_uri() ) ); // deprecated
define( 'FEAST_DIR', trailingslashit( get_stylesheet_directory() ) );
define( 'FEAST_URI', trailingslashit( get_stylesheet_directory_uri() ) );

add_theme_support( 'genesis-responsive-viewport' );

add_theme_support( 'html5' );

add_theme_support( 'custom-background' );

add_theme_support( 'genesis-accessibility', array(
	'headings',
	'search-form',
	'skip-links',
) );

add_theme_support( 'custom-header', array(
	'width'           => 360,
	'flex-width'	  => true,
	'height'          => 100,
	'flex-height'	  => true,
	'header-selector' => '.site-title a',
	'header-text'     => false,
) );
// Remove Genesis custom logo added in Genesis 3.1
remove_action( 'after_setup_theme', 'genesis_output_custom_logo', 11 );

add_theme_support( 'genesis-footer-widgets', 4 );

add_theme_support( 'genesis-after-entry-widget-area' );
/* // removed in version 4.0.0
genesis_register_sidebar( array(
	'id'          => 'before-header',
	'name'        => __( 'Before Header', 'brunch-pro' ),
	'description' => __( 'This is the section before the header.', 'brunch-pro' ),
) );
*/
genesis_register_sidebar( array(
	'id'          => 'home-top',
	'name'        => __( 'Homepage: Above', 'brunch-pro' ),
	'description' => __( 'This section appears above the Homepage content and primary sidebar. It is 100% width. We recommend using the "Brunch Pro - Featured Posts" widget with one-third grid column setting, and the "Genesis: eNews Extended" widget.', 'brunch-pro' ),
) );
genesis_register_sidebar( array(
	'id'          => 'home-middle',
	'name'        => __( 'Homepage: Middle', 'brunch-pro' ),
	'description' => __( 'This is the homepage main content section, we recommend using the "Brunch Pro - Featured Posts" widget with a single post and the content displayed.', 'brunch-pro' ),
) );
genesis_register_sidebar( array(
	'id'          => 'home-bottom',
	'name'        => __( 'Homepage:  Bottom', 'brunch-pro' ),
	'description' => __( 'This is the homepage bottom content section, which is designed for the "Brunch Pro - Featured Posts" widget, with a left-aligned image and an excerpt.', 'brunch-pro' ),
) );
genesis_register_sidebar( array(
	'id'          => 'recipe-index',
	'name'        => __( 'Recipe Index Page Content', 'brunch-pro' ),
	'description' => __( 'This is the recipe index content section. We recommend using multiple "Brunch Pro - Featured Posts" widgets - one for each recipe category. The sidebar controls arae found in the "Secondary Sidebar" widget area.', 'brunch-pro' ),
) );

require_once BRUNCH_PRO_DIR . 'lib/helpers.php';
require_once BRUNCH_PRO_DIR . 'lib/compatibility.php';
require_once BRUNCH_PRO_DIR . 'lib/customize/init.php';

if ( is_admin() ) {
	require_once BRUNCH_PRO_DIR . 'lib/admin/functions.php';
}

add_action( 'after_setup_theme', 'brunch_pro_content_width', 0 );
/**
 * Set the content width and allow it to be filtered directly.
 *
 * @since  1.0.0
 * @access public
 * @return void
 */
function brunch_pro_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'brunch_pro_content_width', 720 );
}

add_action( 'after_setup_theme', 'brunch_pro_load_textdomain' );
/**
 * Load the child theme textdomain.
 *
 * @since  1.0.0
 * @access public
 * @return void
 */
function brunch_pro_load_textdomain() {
	load_child_theme_textdomain(
		'brunch-pro',
		trailingslashit( get_stylesheet_directory() ) . 'languages'
	);
}

add_action( 'init', 'brunch_pro_register_image_sizes', 5 );
/**
 * Register custom image sizes for the theme.
 *
 * @since  1.0.0
 * @access public
 * @return void
 */
function brunch_pro_register_image_sizes() {
	add_image_size( 'horizontal-thumbnail', 720, 360, true );
	add_image_size( 'vertical-thumbnail',   720, 900, true );
	add_image_size( 'square-thumbnail',     360, 360, true );
}

// Remove site layouts (added in version 4.0.0)
genesis_unregister_layout( 'content-sidebar-sidebar' );
genesis_unregister_layout( 'sidebar-content-sidebar' );
genesis_unregister_layout( 'sidebar-sidebar-content' );


add_action( 'init', 'brunch_pro_register_layouts' );

/**
 * Register additional theme layout options.
 *
 * @since  1.0.0
 * @access public
 * @return void
 */

function brunch_pro_register_layouts() {
	genesis_register_layout( 'full-width-slim', array(
		'label' => __( 'Full Width Slim', 'brunch-pro' ),
		'img'   => trailingslashit( get_stylesheet_directory_uri() ) . 'images/layout-slim.gif',
	) );
	genesis_register_layout( 'alt-sidebar-content', array(
		'label' => __( 'Alt Sidebar/Content', 'brunch-pro' ),
		'img'   => trailingslashit( get_stylesheet_directory_uri() ) . 'images/layout-alt-sidebar-content.gif',
	) );
}


add_action( 'widgets_init', 'brunch_pro_register_widgets', 10 );
/**
 * Unregister the default Genesis Featured Posts widget and register all of
 * our custom Brunch Pro widgets.
 *
 * @since  1.0.0
 * @access public
 * @return void
 */
function brunch_pro_register_widgets() {
	if ( ! class_exists( 'Brunch_Pro_Featured_Posts', false ) ) {
		require_once BRUNCH_PRO_DIR . 'lib/widgets/featured-posts/widget.php';
	}

	unregister_widget( 'Genesis_Featured_Post' );
	register_widget( 'Brunch_Pro_Featured_Posts' );
}

add_action( 'wp_enqueue_scripts', 'brunch_pro_enqueue_js' );	
/**	
 * Load all required JavaScript for the theme.	
 *	
 * @since  1.0.0	
 * @access public	
 * @return void	
 */	
function brunch_pro_enqueue_js() {	
	wp_enqueue_script(	
		'brunch-pro-general',	
	 	BRUNCH_PRO_URI . 'js/general.js',	
		array( 'jquery' ),	
		CHILD_THEME_VERSION,	
		true	
	);	
}

// Remove standard Genesis header, replaced with our own feast_filter_genesis_seo_site_title
remove_action( 'genesis_site_description', 'genesis_seo_site_description' );
remove_action( 'wp_head', 'genesis_custom_header_style');

unregister_sidebar( 'header-right' );

// Move main menu.
remove_action( 'genesis_after_header', 'genesis_do_nav' );
add_action( 'genesis_before_header', 'genesis_do_nav' );

add_filter( 'wp_nav_menu_items', 'feast_primary_nav_menu_search', 12, 2 );
/**
 * Append a search box to the primary menu.
 *
 * @since  4.0.1
 * @param  string $menu The current menu output.
 * @param  array  $args The args used for displaying the current menu.
 * @return string $menu The modified menu output.
 */
function feast_primary_nav_menu_search( $menu, $args ) {
	if ( 'primary' !== $args->theme_location || genesis_get_option( 'nav_extras' ) ) {
		return $menu;
	}
	$menu .= sprintf( '<li id="feast-search" class="feast-search menu-item">%s</li>',
		get_search_form ( false )
	);
	return $menu;
}

add_filter( 'genesis_search_text', 'feast_search_text' );
/**
 * Customize search form input box text.
 *
 * @since  4.0.1
 * @return string Modified Shay Bocks credits.
 */
function feast_search_text() {
	return esc_html__( 'Search', 'brunchpro' );
}




add_filter( 'body_class', 'brunch_pro_add_body_class' );
/**
 * Add the theme name class to the body element.
 *
 * @since  1.0.0
 * @param  string $classes The existing body classes.
 * @return string $$classes Modified body classes.
 */
function brunch_pro_add_body_class( $classes ) {
	$classes[] = 'brunch-pro';
	return $classes;
}

/* // removed in version 4.0.0
add_action( 'genesis_before', 'brunch_pro_before_header' );
*/
/**
 * Load an ad section before .site-inner.
 *
 * @since  1.0.0
 * @access public
 * @return void
 */
/* // removed in version 4.0.0
function brunch_pro_before_header() {
	genesis_widget_area( 'before-header', array(
		'before' => '<div id="before-header" class="before-header">',
		'after'  => '</div> <!-- end .before-header -->',
	) );
}
*/

add_action( 'genesis_before_entry', 'brunch_pro_maybe_move_post_info', 0 );
/**
 * Relocate the post info if we're not on a blog archive.
 *
 * @since  1.0.0
 * @access public
 * @return void
 */
function brunch_pro_maybe_move_post_info() {
	if ( is_singular() ) {
		remove_action( 'genesis_entry_header', 'genesis_post_info', 12 );
		add_action( 'genesis_before_entry',  'genesis_post_info', 12 );
	}
}

add_action( 'genesis_after_loop', 'brunch_pro_maybe_disable_sidebars' );
/**
 * Disable the sidebars on custom layouts where they're not needed.
 *
 * @since  1.0.0
 * @access public
 * @uses   genesis_site_layout() Return the site layout for different contexts.
 * @return void
 */
function brunch_pro_maybe_disable_sidebars() {
	$layout = genesis_site_layout();
	if ( in_array( $layout, array( 'full-width-slim', 'alt-sidebar-content' ), true ) ) {
		remove_action( 'genesis_after_content', 'genesis_get_sidebar' );
	}
	if ( 'full-width-slim' === $layout ) {
		remove_action( 'genesis_after_content_sidebar_wrap', 'genesis_get_sidebar_alt' );
	}
}

add_filter( 'genesis_post_info', 'brunch_pro_post_info_filter' );
/**
 * Modify the Genesis post info.
 *
 * @since  1.0.0
 * @access public
 * @return string Modified post info text.
 */
function brunch_pro_post_info_filter() {
	return '[post_date] [post_edit]';
}

/**
 * Return a "Read More" link wrapped in paragraph tags.
 *
 * @since  1.0.0
 * @access public
 * @return string Read more text.
 */
function brunch_pro_get_read_more_link() {
	return sprintf( '<p><a class="more-link" href="%s">%s</a></p>',
		get_permalink(),
		apply_filters( 'brunch_pro_read_more_text', __( 'Read More', 'brunch-pro' ) )
	);
}

add_filter( 'excerpt_more', 'brunch_pro_get_ellipsis' );
/**
 * Return an ellipsis to be used when truncating excerpts.
 *
 * @since  1.0.0
 * @access public
 * @return string an ellipsis.
 */
function brunch_pro_get_ellipsis() {
	return '...';
}

add_filter( 'get_the_content_more_link', 'brunch_pro_content_read_more_link' );
add_filter( 'the_content_more_link', 'brunch_pro_content_read_more_link' );
/**
 * Modify the Genesis and WordPress content read more link.
 *
 * @since  1.0.0
 * @access public
 * @return string Modified read more text.
 */
function brunch_pro_content_read_more_link() {
	return sprintf( '...</p>%s',
		brunch_pro_get_read_more_link()
	);
}

add_filter( 'the_excerpt', 'brunch_pro_excerpt_read_more_link' );
/**
 * Modify the WordPress excerpt by forcing a read more link to be appended.
 *
 * @since  1.0.0
 * @access public
 * @param  string $output the default excerpt output.
 * @return string $output Modified excerpt with a read more link added.
 */
function brunch_pro_excerpt_read_more_link( $output ) {
	return $output . brunch_pro_get_read_more_link();
}

add_filter( 'genesis_seo_title', 'feast_filter_genesis_seo_site_title', 10, 2 );
/**
 * Replace genesis_seo_title to display normal header image at whatever dimensions user uploaded at
 * See: https://feastdesignco.com/rethinking-the-header/
 *
 * @since  3.1.7
 * @access public
 * @param  string $creds Default credits.
 * @return string Modified Feast credits.
 */
function feast_filter_genesis_seo_site_title( $title, $inside ){
	$child_inside = sprintf( '<a href="%s" title="%s" ><img src="%s" title="%s" alt="%s logo" data-pin-nopin="true" /></a>', 
				trailingslashit( home_url() ), 
				esc_attr( get_bloginfo( 'name' ) ), 
				get_header_image(),
				esc_attr( get_bloginfo( 'name' ) ), 
				esc_attr( get_bloginfo( 'name' ) ) 
			);
	if( get_header_image() == '' ) { // overwrite $child_inside if no header image specified
		$child_inside = sprintf( '<a href="%s">%s</a>', 
					trailingslashit( home_url() ), 
					esc_attr( get_bloginfo( 'name' ) )
				);
	}
	$title = str_replace( $inside, $child_inside, $title );
	return $title;		
}



remove_action( 'genesis_footer', 'genesis_do_footer' );
add_filter( 'feast_filter_footer_output', 'do_shortcode', 20 );
add_action('genesis_footer','feast_footer_creds_text', 12);
/**
 * Customize the footer text via Customize > Theme Settings > Footer
 * changed from filter on genesis_footer_creds_text to action on genesis_footer in 4.2.0 for Genesis 3.1.0+
 *
 * @since  3.2.0
 * @access public
 * @param  string $creds Default credits.
 * @return string Modified Feast credits.
 */
function feast_footer_creds_text ( ) {
	$footeroutput =  sprintf( 'Copyright &copy; %u %s on the <a href="%s" target="_blank" rel="noopener">%s</a><br/>%s',
				  date( 'Y' ),
				  get_bloginfo( 'name' ),
				  CHILD_THEME_URL,
				  CHILD_THEME_NAME,
				  '' // additional custom footer text here
				 );
	
	$customeroverride = wp_kses_post( genesis_get_option( 'footer_text' ) );
	// check for generic Genesis footer text (default from first time install)
	if(!strpos("buffer".strtolower($customeroverride),"studiopress") && !strpos("buffer".strtolower($customeroverride),"genesis")  && $customeroverride!=''){ 
		// if customer has specified custom text, override child theme default 
		$footeroutput = $customeroverride;
	}
	
	// considered using genesis_footer_output but that's used in different Genesis setup
	$footeroutput = apply_filters( 'feast_filter_footer_output', "<p>".$footeroutput."</p>");
	
	echo $footeroutput;
	
}
